This crate contains kube-rs compatible bindings for Kubernetes custom resources for the trident.netapp.io group. Each binding is generated with kopium, updated and released weekly.
Available Custom Resources
trident.netapp.io/v1
TridentOrchestrator